==> kmlofax-0.6.3.tar.gz: kmlofax-0.6.3/kmlofax/filters.h <==
/*
    KMLOFax

    A utility to process facsimile received with the ELSA
    MicroLink(tm) Office modem.

    Copyright (C) 1999-2000 Oliver Gantz <Oliver.Gantz@epost.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    ------
    ELSA and MicroLink are trademarks of ELSA AG, Aachen.
    PostScript(R) is a registered trademark of Adobe Systems Incorporated.
*/

#ifndef FILTERS_H
#define FILTERS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <tiffio.h>

#include "mlofile.h"



class MLOFilter
{
public:
	MLOFilter();
	MLOFilter(const char *infile);
	~MLOFilter();

	void setFile(const char *infile);
	
	bool convertFile(FILE *stream);

private:
	void init();

protected:
	MLOFile mlofile;

	FILE *f;
};



class MLO2PSFilter : public MLOFilter
{
public:
	MLO2PSFilter();
	MLO2PSFilter(const char *infile);
	~MLO2PSFilter();

	void setFormat(int format);
	void setLevel2(bool l2);
	void setInterpolate(bool interp);
	void setRange(int first, int last);
	void setCopies(int copies);
	void setMargins(int left, int right, int top, int bottom);

	bool convertFile(FILE *stream, const QString& sender);

private:
	void init();

	bool convertPage(int fax_page, int sub_page, int ps_page, int lines, int strech_y);
	
	void writeBase85(uchar c);
	void flushBase85();

	void writeImageData(char c);
	void flushImageData();

	void resetImageData();

	int paper_x, paper_y;
	bool level2;
	bool interpolate;
	int first_page, last_page;
	int doc_copies;
	int l_margin, r_margin, t_margin, b_margin;

	int size_x, size_y;
	int view_x, view_y;
	int scale_x, scale_y;
	int trans_x, trans_y;

	uchar base85_buff[4];
	int base85_ind;

	char image_buff[254];
	int image_ind;
};



class MLO2TiffFilter : public MLOFilter
{
public:
	MLO2TiffFilter();
	MLO2TiffFilter(const char *infile);
	~MLO2TiffFilter();

	void setFile(const char *infile);
	
	void setCompression(int comp);
	void setRange(int first, int last);
	
	bool convertFile(const char *outfile, const QString& sender);

private:	
	void init();

	bool convertPage(int page);

protected:
	TIFF *tif;
	int first_page, last_page;
	uint16 compression;
	QString m_sender;
	char time_str[20];
};



#endif // FILTERS_H

==> kmlofax-2.0.tar.gz: kmlofax-2.0/kmlofax/filters.h <==
/*
    KMLOFax

    A utility to process facsimiles received with the ELSA
    MicroLink(tm) Office modem.

    Copyright (C) 1999-2001 Oliver Gantz <Oliver.Gantz@epost.de>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    ------
    ELSA and MicroLink are trademarks of ELSA AG, Aachen.
    PostScript(R) is a registered trademark of Adobe Systems Incorporated.
*/

#ifndef FILTERS_H
#define FILTERS_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <tiffio.h>

#include "mlofile.h"



class MLOFilter
{
public:
	MLOFilter();
	MLOFilter(const QString& infile);
	~MLOFilter();

	void setFile(const QString& infile);
	
	bool convertFile(FILE *stream);

private:
	void init();

protected:
	MLOFile mlofile;

	FILE *f;
};



class MLO2PSFilter : public MLOFilter
{
public:
	MLO2PSFilter();
	MLO2PSFilter(const QString& infile);
	~MLO2PSFilter();

	void setFormat(int format);
	void setLevel2(bool l2);
	void setInterpolate(bool interp);
	void setRange(int first, int last);
	void setCopies(int copies);
	void setMargins(int left, int right, int top, int bottom);

	bool convertFile(FILE *stream);

private:
	void init();

	bool convertPage(int fax_page, int sub_page, int ps_page, int lines, int strech_y);
	
	void writeBase85(uchar c);
	void flushBase85();

	void writeImageData(char c);
	void flushImageData();

	void resetImageData();

	int paper_x, paper_y;
	bool level2;
	bool interpolate;
	int first_page, last_page;
	int doc_copies;
	int l_margin, r_margin, t_margin, b_margin;

	int size_x, size_y;
	int view_x, view_y;
	int scale_x, scale_y;
	int trans_x, trans_y;

	uchar base85_buff[4];
	int base85_ind;

	char image_buff[254];
	int image_ind;
};



class MLO2TiffFilter : public MLOFilter
{
public:
	MLO2TiffFilter();
	MLO2TiffFilter(const QString& infile);
	~MLO2TiffFilter();

	void setFile(const QString& infile);
	
	void setCompression(int comp);
	void setRange(int first, int last);
	
	bool convertFile(const QString& outfile);

private:	
	void init();

	bool convertPage(int page);

protected:
	TIFF *tif;
	int first_page, last_page;
	uint16 compression;
	char time_str[20];
};



#endif // FILTERS_H
